package com.ruoyi.app.service;

import java.util.List;
import com.ruoyi.app.domain.AppStorage;

/**
 * 仓库Service接口
 *
 * @author ruoyi
 * @date 2025-03-04
 */
public interface IAppStorageService
{
    /**
     * 查询仓库
     *
     * @param id 仓库主键
     * @return 仓库
     */
    public AppStorage selectAppStorageById(Long id);

    /**
     * 查询仓库列表
     *
     * @param appStorage 仓库
     * @return 仓库集合
     */
    public List<AppStorage> selectAppStorageList(AppStorage appStorage);

    /**
     * 新增仓库
     *
     * @param appStorage 仓库
     * @return 结果
     */
    public int insertAppStorage(AppStorage appStorage);

    /**
     * 修改仓库
     *
     * @param appStorage 仓库
     * @return 结果
     */
    public int updateAppStorage(AppStorage appStorage);

    /**
     * 批量删除仓库
     *
     * @param ids 需要删除的仓库主键集合
     * @return 结果
     */
    public int deleteAppStorageByIds(Long[] ids);

    /**
     * 删除仓库信息
     *
     * @param id 仓库主键
     * @return 结果
     */
    public int deleteAppStorageById(Long id);
}
