package com.ruoyi.web.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.app.domain.AppStorage;
import com.ruoyi.app.service.IAppStorageService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 仓库Controller
 *
 * @author ruoyi
 * @date 2025-03-04
 */
@RestController
@RequestMapping("/app/storage")
public class AppStorageController extends BaseController
{
    @Autowired
    private IAppStorageService appStorageService;

    /**
     * 查询仓库列表
     */
    @PreAuthorize("@ss.hasPermi('app:storage:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppStorage appStorage)
    {
        startPage();
        List<AppStorage> list = appStorageService.selectAppStorageList(appStorage);
        return getDataTable(list);
    }

    /**
     * 导出仓库列表
     */
    @PreAuthorize("@ss.hasPermi('app:storage:export')")
    @Log(title = "仓库", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppStorage appStorage)
    {
        List<AppStorage> list = appStorageService.selectAppStorageList(appStorage);
        ExcelUtil<AppStorage> util = new ExcelUtil<AppStorage>(AppStorage.class);
        util.exportExcel(response, list, "仓库数据");
    }

    /**
     * 获取仓库详细信息
     */
    @PreAuthorize("@ss.hasPermi('app:storage:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appStorageService.selectAppStorageById(id));
    }

    /**
     * 新增仓库
     */
    @PreAuthorize("@ss.hasPermi('app:storage:add')")
    @Log(title = "仓库", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppStorage appStorage)
    {
        return toAjax(appStorageService.insertAppStorage(appStorage));
    }

    /**
     * 修改仓库
     */
    @PreAuthorize("@ss.hasPermi('app:storage:edit')")
    @Log(title = "仓库", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppStorage appStorage)
    {
        return toAjax(appStorageService.updateAppStorage(appStorage));
    }

    /**
     * 删除仓库
     */
    @PreAuthorize("@ss.hasPermi('app:storage:remove')")
    @Log(title = "仓库", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appStorageService.deleteAppStorageByIds(ids));
    }
}
